@@ -1,35 +1,34 @@
-#include <glib.h>
-#include <string.h>
-
-#include "GSettingsBackend.h"
 #include "IBusChewingPreEdit.h"
 #include "IBusChewingUtil.h"
 #include "MakerDialogUtil.h"
+#include "ibus-chewing-engine-private.h"
+#include "ibus-chewing-engine.h"
 #include "test-util.h"
+#include <glib.h>
+#include <stdio.h>
+#include <string.h>
 
 #include "IBusChewingPreEdit-private.h"
 
 #define TEST_RUN_THIS(f) add_test_case("IBusChewingPreEdit", f)
-#define TEST_CASE_INIT()                                                       \
-    reset_properties_default(self);                                            \
-    ibus_chewing_pre_edit_clear(self);                                         \
-    ibus_chewing_pre_edit_set_full_half_mode(self, FALSE);                     \
+#define TEST_CASE_INIT()                                                                           \
+    g_object_set(G_OBJECT(self->engine), "conversion-engine", "chewing", NULL);                    \
+    ibus_chewing_pre_edit_clear(self);                                                             \
+    ibus_chewing_pre_edit_set_full_half_mode(self, FALSE);                                         \
     ibus_chewing_pre_edit_set_chi_eng_mode(self, TRUE)
 
 static IBusChewingPreEdit *self = NULL;
 
 /*== Utility functions start ==*/
-#define assert_pre_edit_substring(needle, begin, length)                       \
-    assert_substring(ibus_chewing_pre_edit_get_pre_edit(self), needle, begin,  \
-                     length)
+#define assert_pre_edit_substring(needle, begin, length)                                           \
+    assert_substring(ibus_chewing_pre_edit_get_pre_edit(self), needle, begin, length)
 
 void assert_outgoing_pre_edit(const gchar *outgoing, const gchar *pre_edit) {
     g_assert_cmpstr(outgoing, ==, ibus_chewing_pre_edit_get_outgoing(self));
     g_assert_cmpstr(pre_edit, ==, ibus_chewing_pre_edit_get_pre_edit(self));
 }
 
-void assert_substring(const gchar *haystack, const gchar *needle, gint begin,
-                      gint length) {
+void assert_substring(const gchar *haystack, const gchar *needle, gint begin, gint length) {
     gchar *subStr = g_utf8_substring(haystack, begin, begin + length);
 
     g_assert_cmpstr(subStr, ==, needle);
@@ -41,48 +40,35 @@ void key_press_from_key_sym(KSym keySym, KeyModifiers modifiers) {
     case IBUS_KEY_Shift_L:
     case IBUS_KEY_Shift_R:
         ibus_chewing_pre_edit_process_key(self, keySym, modifiers);
-        ibus_chewing_pre_edit_process_key(
-            self, keySym, modifiers | IBUS_RELEASE_MASK | IBUS_SHIFT_MASK);
+        ibus_chewing_pre_edit_process_key(self, keySym,
+                                          modifiers | IBUS_RELEASE_MASK | IBUS_SHIFT_MASK);
         break;
     default:
         if (modifiers & IBUS_SHIFT_MASK) {
             ibus_chewing_pre_edit_process_key(self, IBUS_KEY_Shift_L, 0);
         }
         ibus_chewing_pre_edit_process_key(self, keySym, modifiers);
-        ibus_chewing_pre_edit_process_key(self, keySym,
-                                          modifiers | IBUS_RELEASE_MASK);
+        ibus_chewing_pre_edit_process_key(self, keySym, modifiers | IBUS_RELEASE_MASK);
         if (modifiers & IBUS_SHIFT_MASK) {
-            ibus_chewing_pre_edit_process_key(
-                self, IBUS_KEY_Shift_L, IBUS_SHIFT_MASK | IBUS_RELEASE_MASK);
+            ibus_chewing_pre_edit_process_key(self, IBUS_KEY_Shift_L,
+                                              IBUS_SHIFT_MASK | IBUS_RELEASE_MASK);
         }
         break;
     }
 
-    printf("key_press_from_key_sym(%x(%s),%x), buffer=|%s| outgoing=|%s|\n",
-           keySym, key_sym_get_name(keySym), modifiers,
-           ibus_chewing_pre_edit_get_pre_edit(self),
+    printf("key_press_from_key_sym(%x(%s),%x), buffer=|%s| outgoing=|%s|\n", keySym,
+           key_sym_get_name(keySym), modifiers, ibus_chewing_pre_edit_get_pre_edit(self),
            ibus_chewing_pre_edit_get_outgoing(self));
 }
 
 void key_press_from_string(const gchar *keySeq) {
-    gint i;
+    guint i;
 
     for (i = 0; i < strlen(keySeq); i++) {
         key_press_from_key_sym((guint)keySeq[i], 0);
     }
 }
 
-void reset_properties_default(IBusChewingPreEdit *self) {
-    gsize size = mkdg_properties_size(self->iProperties->properties);
-
-    for (gsize i = 0; i < size; i++) {
-        PropertyContext *ctx =
-            mkdg_properties_index(self->iProperties->properties, i);
-        property_context_default(ctx);
-    }
-}
-
-/*== Unit cases start ==*/
 EventResponse filter_modifiers_test_0_0() {
     KeyModifiers allow = 0, unmaskedMod = 0;
 
@@ -133,8 +119,7 @@ EventResponse filter_modifiers_test_shift_control() {
 }
 
 EventResponse filter_modifiers_test_shift_shift_control() {
-    KeyModifiers allow = IBUS_SHIFT_MASK,
-                 unmaskedMod = IBUS_SHIFT_MASK | IBUS_CONTROL_MASK;
+    KeyModifiers allow = IBUS_SHIFT_MASK, unmaskedMod = IBUS_SHIFT_MASK | IBUS_CONTROL_MASK;
     filter_modifiers(allow);
     return EVENT_RESPONSE_PROCESS;
 }
@@ -148,18 +133,15 @@ void filter_modifiers_test() {
     g_assert(filter_modifiers_test_shift_0() == EVENT_RESPONSE_PROCESS);
     g_assert(filter_modifiers_test_shift_shift() == EVENT_RESPONSE_PROCESS);
     g_assert(filter_modifiers_test_shift_control() == EVENT_RESPONSE_IGNORE);
-    g_assert(filter_modifiers_test_shift_shift_control() ==
-             EVENT_RESPONSE_IGNORE);
+    g_assert(filter_modifiers_test_shift_shift_control() == EVENT_RESPONSE_IGNORE);
 }
 
 void self_key_sym_fix_test() {
+    TEST_CASE_INIT();
     ibus_chewing_pre_edit_set_chi_eng_mode(self, FALSE);
 
-    ibus_chewing_pre_edit_set_property_string(self, "chi-eng-mode-toggle",
-                                              "caps_lock");
-
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "no control");
+    g_object_set(G_OBJECT(self->engine), "chi-eng-mode-toggle", "caps_lock", "default-english-case",
+                 "no default", NULL);
     g_assert(self_key_sym_fix(self, '1', 0) == '1');
     g_assert(self_key_sym_fix(self, 'a', 0) == 'a');
     g_assert(self_key_sym_fix(self, 'A', 0) == 'A');
@@ -167,13 +149,10 @@ void self_key_sym_fix_test() {
     g_assert(self_key_sym_fix(self, 'A', IBUS_SHIFT_MASK) == 'A');
     g_assert(self_key_sym_fix(self, 'a', IBUS_LOCK_MASK) == 'a');
     g_assert(self_key_sym_fix(self, 'A', IBUS_LOCK_MASK) == 'A');
-    g_assert(self_key_sym_fix(self, 'a', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'a');
-    g_assert(self_key_sym_fix(self, 'A', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'A');
+    g_assert(self_key_sym_fix(self, 'a', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'a');
+    g_assert(self_key_sym_fix(self, 'A', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'A');
 
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "lowercase");
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "lowercase", NULL);
     g_assert(self_key_sym_fix(self, '2', 0) == '2');
     g_assert(self_key_sym_fix(self, 'b', 0) == 'b');
     g_assert(self_key_sym_fix(self, 'B', 0) == 'b');
@@ -181,67 +160,51 @@ void self_key_sym_fix_test() {
     g_assert(self_key_sym_fix(self, 'B', IBUS_SHIFT_MASK) == 'B');
     g_assert(self_key_sym_fix(self, 'b', IBUS_LOCK_MASK) == 'b');
     g_assert(self_key_sym_fix(self, 'B', IBUS_LOCK_MASK) == 'b');
-    g_assert(self_key_sym_fix(self, 'b', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'B');
-    g_assert(self_key_sym_fix(self, 'B', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'B');
+    g_assert(self_key_sym_fix(self, 'b', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'B');
+    g_assert(self_key_sym_fix(self, 'B', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'B');
 
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "uppercase");
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "uppercase", NULL);
     g_assert(self_key_sym_fix(self, 'c', 0) == 'C');
     g_assert(self_key_sym_fix(self, 'C', 0) == 'C');
     g_assert(self_key_sym_fix(self, 'c', IBUS_SHIFT_MASK) == 'c');
     g_assert(self_key_sym_fix(self, 'C', IBUS_SHIFT_MASK) == 'c');
     g_assert(self_key_sym_fix(self, 'c', IBUS_LOCK_MASK) == 'C');
     g_assert(self_key_sym_fix(self, 'C', IBUS_LOCK_MASK) == 'C');
-    g_assert(self_key_sym_fix(self, 'c', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'c');
-    g_assert(self_key_sym_fix(self, 'C', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'c');
+    g_assert(self_key_sym_fix(self, 'c', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'c');
+    g_assert(self_key_sym_fix(self, 'C', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'c');
 
-    ibus_chewing_pre_edit_set_property_string(self, "chi-eng-mode-toggle",
-                                              "shift");
-
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "no control");
+    g_object_set(G_OBJECT(self->engine), "chi-eng-mode-toggle", "shift", "default-english-case",
+                 "no default", NULL);
     g_assert(self_key_sym_fix(self, 'd', 0) == 'd');
     g_assert(self_key_sym_fix(self, 'D', 0) == 'D');
     g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK) == 'd');
     g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK) == 'D');
     g_assert(self_key_sym_fix(self, 'd', IBUS_LOCK_MASK) == 'd');
     g_assert(self_key_sym_fix(self, 'D', IBUS_LOCK_MASK) == 'D');
-    g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'd');
-    g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'D');
+    g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'd');
+    g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'D');
 
-    /* This should act as "no control" */
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "lowercase");
+    /* This should act as "no default" */
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "lowercase", NULL);
     g_assert(self_key_sym_fix(self, 'd', 0) == 'd');
     g_assert(self_key_sym_fix(self, 'D', 0) == 'D');
     g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK) == 'd');
     g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK) == 'D');
     g_assert(self_key_sym_fix(self, 'd', IBUS_LOCK_MASK) == 'd');
     g_assert(self_key_sym_fix(self, 'D', IBUS_LOCK_MASK) == 'D');
-    g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'd');
-    g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'D');
+    g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'd');
+    g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'D');
 
-    /* This should act as "no control" */
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "uppercase");
+    /* This should act as "no default" */
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "uppercase", NULL);
     g_assert(self_key_sym_fix(self, 'd', 0) == 'd');
     g_assert(self_key_sym_fix(self, 'D', 0) == 'D');
     g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK) == 'd');
     g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK) == 'D');
     g_assert(self_key_sym_fix(self, 'd', IBUS_LOCK_MASK) == 'd');
     g_assert(self_key_sym_fix(self, 'D', IBUS_LOCK_MASK) == 'D');
-    g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'd');
-    g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'D');
+    g_assert(self_key_sym_fix(self, 'd', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'd');
+    g_assert(self_key_sym_fix(self, 'D', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'D');
 
     /* In Chinese mode, the case should be determine by the shift, not the
      * case itself.
@@ -250,89 +213,67 @@ void self_key_sym_fix_test() {
      */
     ibus_chewing_pre_edit_set_chi_eng_mode(self, TRUE);
 
-    ibus_chewing_pre_edit_set_property_string(self, "chi-eng-mode-toggle",
-                                              "caps_lock");
-
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "no control");
+    g_object_set(G_OBJECT(self->engine), "chi-eng-mode-toggle", "caps_lock", "default-english-case",
+                 "no default", NULL);
     g_assert(self_key_sym_fix(self, 'e', 0) == 'e');
     g_assert(self_key_sym_fix(self, 'E', 0) == 'e');
     g_assert(self_key_sym_fix(self, 'e', IBUS_SHIFT_MASK) == 'E');
     g_assert(self_key_sym_fix(self, 'E', IBUS_SHIFT_MASK) == 'E');
     g_assert(self_key_sym_fix(self, 'e', IBUS_LOCK_MASK) == 'e');
     g_assert(self_key_sym_fix(self, 'E', IBUS_LOCK_MASK) == 'e');
-    g_assert(self_key_sym_fix(self, 'e', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'E');
-    g_assert(self_key_sym_fix(self, 'E', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'E');
+    g_assert(self_key_sym_fix(self, 'e', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'E');
+    g_assert(self_key_sym_fix(self, 'E', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'E');
 
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "lowercase");
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "lowercase", NULL);
     g_assert(self_key_sym_fix(self, 'f', 0) == 'f');
     g_assert(self_key_sym_fix(self, 'F', 0) == 'f');
     g_assert(self_key_sym_fix(self, 'f', IBUS_SHIFT_MASK) == 'F');
     g_assert(self_key_sym_fix(self, 'F', IBUS_SHIFT_MASK) == 'F');
     g_assert(self_key_sym_fix(self, 'f', IBUS_LOCK_MASK) == 'f');
     g_assert(self_key_sym_fix(self, 'F', IBUS_LOCK_MASK) == 'f');
-    g_assert(self_key_sym_fix(self, 'f', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'F');
-    g_assert(self_key_sym_fix(self, 'F', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'F');
+    g_assert(self_key_sym_fix(self, 'f', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'F');
+    g_assert(self_key_sym_fix(self, 'F', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'F');
 
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "uppercase");
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "uppercase", NULL);
     g_assert(self_key_sym_fix(self, 'g', 0) == 'g');
     g_assert(self_key_sym_fix(self, 'G', 0) == 'g');
     g_assert(self_key_sym_fix(self, 'g', IBUS_SHIFT_MASK) == 'G');
     g_assert(self_key_sym_fix(self, 'G', IBUS_SHIFT_MASK) == 'G');
     g_assert(self_key_sym_fix(self, 'g', IBUS_LOCK_MASK) == 'g');
     g_assert(self_key_sym_fix(self, 'G', IBUS_LOCK_MASK) == 'g');
-    g_assert(self_key_sym_fix(self, 'g', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'G');
-    g_assert(self_key_sym_fix(self, 'G', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'G');
+    g_assert(self_key_sym_fix(self, 'g', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'G');
+    g_assert(self_key_sym_fix(self, 'G', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'G');
 
-    ibus_chewing_pre_edit_set_property_string(self, "chi-eng-mode-toggle",
-                                              "shift");
-
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "no control");
+    g_object_set(G_OBJECT(self->engine), "chi-eng-mode-toggle", "shift", "default-english-case",
+                 "no default", NULL);
     g_assert(self_key_sym_fix(self, 'h', 0) == 'h');
     g_assert(self_key_sym_fix(self, 'H', 0) == 'h');
     g_assert(self_key_sym_fix(self, 'h', IBUS_SHIFT_MASK) == 'H');
     g_assert(self_key_sym_fix(self, 'H', IBUS_SHIFT_MASK) == 'H');
     g_assert(self_key_sym_fix(self, 'h', IBUS_LOCK_MASK) == 'h');
     g_assert(self_key_sym_fix(self, 'H', IBUS_LOCK_MASK) == 'h');
-    g_assert(self_key_sym_fix(self, 'h', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'H');
-    g_assert(self_key_sym_fix(self, 'H', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'H');
+    g_assert(self_key_sym_fix(self, 'h', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'H');
+    g_assert(self_key_sym_fix(self, 'H', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'H');
 
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "lowercase");
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "lowercase", NULL);
     g_assert(self_key_sym_fix(self, 'i', 0) == 'i');
     g_assert(self_key_sym_fix(self, 'I', 0) == 'i');
     g_assert(self_key_sym_fix(self, 'i', IBUS_SHIFT_MASK) == 'I');
     g_assert(self_key_sym_fix(self, 'I', IBUS_SHIFT_MASK) == 'I');
     g_assert(self_key_sym_fix(self, 'i', IBUS_LOCK_MASK) == 'i');
     g_assert(self_key_sym_fix(self, 'I', IBUS_LOCK_MASK) == 'i');
-    g_assert(self_key_sym_fix(self, 'i', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'I');
-    g_assert(self_key_sym_fix(self, 'I', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'I');
+    g_assert(self_key_sym_fix(self, 'i', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'I');
+    g_assert(self_key_sym_fix(self, 'I', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'I');
 
-    ibus_chewing_pre_edit_set_property_string(self, "default-english-case",
-                                              "uppercase");
+    g_object_set(G_OBJECT(self->engine), "default-english-case", "uppercase", NULL);
     g_assert(self_key_sym_fix(self, 'j', 0) == 'j');
     g_assert(self_key_sym_fix(self, 'J', 0) == 'j');
     g_assert(self_key_sym_fix(self, 'j', IBUS_SHIFT_MASK) == 'J');
     g_assert(self_key_sym_fix(self, 'J', IBUS_SHIFT_MASK) == 'J');
     g_assert(self_key_sym_fix(self, 'j', IBUS_LOCK_MASK) == 'j');
     g_assert(self_key_sym_fix(self, 'J', IBUS_LOCK_MASK) == 'j');
-    g_assert(self_key_sym_fix(self, 'j', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'J');
-    g_assert(self_key_sym_fix(self, 'J', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) ==
-             'J');
+    g_assert(self_key_sym_fix(self, 'j', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'J');
+    g_assert(self_key_sym_fix(self, 'J', IBUS_SHIFT_MASK | IBUS_LOCK_MASK) == 'J');
 }
 
 void self_handle_key_sym_default_test() {
@@ -383,6 +324,25 @@ void self_handle_key_sym_default_test() {
 /*== Test cases start ==*/
 void free_test() { ibus_chewing_pre_edit_free(self); }
 
+void process_key_default_english_test() {
+    TEST_CASE_INIT();
+    g_object_set(G_OBJECT(self->engine), "default-use-english-mode", TRUE, NULL);
+    g_object_set(G_OBJECT(self->engine), "chi-eng-mode-toggle", "shift", NULL);
+
+    ibus_chewing_engine_enable(self->engine);
+    // English inputs at the beginning bypasses any processing
+    key_press_from_string("ibus-chewing ");
+    key_press_from_key_sym(IBUS_KEY_Shift_L, 0);
+    key_press_from_string("gj bj4z83");
+    key_press_from_key_sym(IBUS_KEY_Return, 0);
+    assert_outgoing_pre_edit("輸入法", "");
+
+    ibus_chewing_pre_edit_clear(self);
+    assert_outgoing_pre_edit("", "");
+
+    g_object_set(G_OBJECT(self->engine), "default-use-english-mode", FALSE, NULL);
+}
+
 /* Chinese mode: "中文" (5j/ jp6) and Enter*/
 void process_key_normal_test() {
     TEST_CASE_INIT();
@@ -426,9 +386,7 @@ void process_key_text_with_symbol_test() {
 void process_key_mix_test() {
     TEST_CASE_INIT();
 
-    ibus_chewing_pre_edit_set_property_string(self, "chi-eng-mode-toggle",
-                                              "shift");
-
+    g_object_set(G_OBJECT(self->engine), "chi-eng-mode-toggle", "shift", NULL);
     key_press_from_string("5k4g4");
     key_press_from_key_sym(IBUS_KEY_Shift_L, 0);
     key_press_from_string("ibus-chewing ");
@@ -466,10 +424,8 @@ void process_key_buffer_full_handling_test() {
 /* 程式 */
 void process_key_down_arrow_test() {
     TEST_CASE_INIT();
-    ibus_chewing_pre_edit_set_apply_property_boolean(self, "plain-zhuyin",
-                                                     FALSE);
-    ibus_chewing_pre_edit_set_apply_property_boolean(
-        self, "phrase-choice-from-last", TRUE);
+
+    g_object_set(G_OBJECT(self->engine), "phrase-choice-from-last", TRUE, NULL);
     key_press_from_string("t/6g4");
     key_press_from_key_sym(IBUS_KEY_Down, 0);
     key_press_from_string("1");
@@ -478,10 +434,10 @@ void process_key_down_arrow_test() {
     key_press_from_string("2");
     assert_outgoing_pre_edit("", "程式");
 
-    key_press_from_key_sym(IBUS_KEY_Down, 0);
-    key_press_from_key_sym(IBUS_KEY_Down, 0);
-    key_press_from_string("4");
-    assert_pre_edit_substring("世", 1, 1);
+    // key_press_from_key_sym(IBUS_KEY_Down, 0);
+    // key_press_from_key_sym(IBUS_KEY_Down, 0);
+    // key_press_from_string("4");
+    // assert_pre_edit_substring("世", 1, 1);
 
     ibus_chewing_pre_edit_clear(self);
     assert_outgoing_pre_edit("", "");
@@ -496,8 +452,6 @@ void process_key_shift_and_caps_test() {
 #if 0
 
     TEST_CASE_INIT();
-    ibus_chewing_pre_edit_set_apply_property_boolean(self,
-                                                     "plain-zhuyin", FALSE);
     ibus_chewing_pre_edit_set_apply_property_boolean(self,
                                                      "space-as-selection",
                                                      FALSE);
@@ -546,8 +500,6 @@ void process_key_shift_and_caps_test() {
 }
 
 void full_half_shape_test() {
-    ibus_chewing_pre_edit_set_apply_property_boolean(self, "plain-zhuyin",
-                                                     FALSE);
     g_assert(ibus_chewing_pre_edit_get_chi_eng_mode(self));
     ibus_chewing_pre_edit_toggle_chi_eng_mode(self);
     g_assert(!ibus_chewing_pre_edit_get_chi_eng_mode(self));
@@ -567,10 +519,7 @@ void full_half_shape_test() {
 }
 
 void plain_zhuyin_test() {
-    ibus_chewing_pre_edit_set_apply_property_boolean(self, "plain-zhuyin",
-                                                     TRUE);
-
-    g_assert(ibus_chewing_pre_edit_get_property_boolean(self, "plain-zhuyin"));
+    g_object_set(G_OBJECT(self->engine), "conversion-engine", "simple", NULL);
 
     key_press_from_string("y ");
 
@@ -581,7 +530,7 @@ void plain_zhuyin_test() {
      */
     /* assert_outgoing_pre_edit("","資"); */
     key_press_from_string("4");
-    assert_outgoing_pre_edit("吱", "");
+    assert_outgoing_pre_edit("", "吱");
     /* Candidate window should be hidden */
     g_assert(!ibus_chewing_pre_edit_has_flag(self, FLAG_TABLE_SHOW));
 
@@ -591,55 +540,44 @@ void plain_zhuyin_test() {
 
 /*  你好，*/
 void plain_zhuyin_shift_symbol_test() {
-    ibus_chewing_pre_edit_set_apply_property_boolean(self, "plain-zhuyin",
-                                                     TRUE);
-    g_assert(ibus_chewing_pre_edit_get_property_boolean(self, "plain-zhuyin"));
-
-    ibus_chewing_pre_edit_set_property_string(self, "chi-eng-mode-toggle",
-                                              "shift");
+    g_object_set(G_OBJECT(self->engine), "conversion-engine", "simple", "chi-eng-mode-toggle",
+                 "shift", NULL);
 
     key_press_from_string("su31cl31");
 
     /* ， */
     key_press_from_key_sym(IBUS_KEY_less, IBUS_SHIFT_MASK);
-    /* Candidate window should be shown */
-    g_assert(ibus_chewing_pre_edit_has_flag(self, FLAG_TABLE_SHOW));
-    key_press_from_string("1");
 
     /* Candidate window should be hidden */
     g_assert(!ibus_chewing_pre_edit_has_flag(self, FLAG_TABLE_SHOW));
 
-    assert_outgoing_pre_edit("你好，", "");
+    assert_outgoing_pre_edit("", "你好，");
 
     /* 打電話  */
     key_press_from_string("28312u041cj841");
-    assert_outgoing_pre_edit("你好，打電話", "");
+    assert_outgoing_pre_edit("", "你好，打電話");
 
     /* ； */
     key_press_from_key_sym(IBUS_KEY_quotedbl, IBUS_SHIFT_MASK);
-    key_press_from_string("1");
-    assert_outgoing_pre_edit("你好，打電話；", "");
+    assert_outgoing_pre_edit("", "你好，打電話；");
 
     /* Mix with shift */
 
     key_press_from_key_sym(IBUS_KEY_Shift_L, IBUS_SHIFT_MASK);
 
-    /* String is bypass in English mode */
     key_press_from_string("4321-9876 ");
-
-    assert_outgoing_pre_edit("你好，打電話；", "");
+    assert_outgoing_pre_edit("", "你好，打電話；4321-9876 ");
     key_press_from_key_sym(IBUS_KEY_Shift_L, IBUS_SHIFT_MASK);
     /* "來訂餐" */
     key_press_from_string("x9612u/42h0 2");
-    assert_outgoing_pre_edit("你好，打電話；來訂餐", "");
+    assert_outgoing_pre_edit("", "你好，打電話；4321-9876 來訂餐");
 
     ibus_chewing_pre_edit_clear(self);
     assert_outgoing_pre_edit("", "");
 }
 
 void plain_zhuyin_full_half_shape_test() {
-    ibus_chewing_pre_edit_set_apply_property_boolean(self, "plain-zhuyin",
-                                                     TRUE);
+    g_object_set(G_OBJECT(self->engine), "conversion-engine", "simple", NULL);
     g_assert(ibus_chewing_pre_edit_get_chi_eng_mode(self));
     ibus_chewing_pre_edit_toggle_chi_eng_mode(self);
     g_assert(!ibus_chewing_pre_edit_get_chi_eng_mode(self));
@@ -689,8 +627,7 @@ void test_ibus_chewing_pre_edit_set_chi_eng_mode() {
 void test_space_as_selection() {
     /* GitHub #79: Cannot input space when "space to select" is enabled  */
     TEST_CASE_INIT();
-    ibus_chewing_pre_edit_set_apply_property_boolean(self, "space-as-selection",
-                                                     TRUE);
+    g_object_set(G_OBJECT(self->engine), "space-as-selection", TRUE, NULL);
 
     key_press_from_key_sym(IBUS_KEY_space, 0);
     assert_outgoing_pre_edit(" ", "");
@@ -700,8 +637,7 @@ void test_arrow_keys_buffer_empty() {
     /* GitHub #50: Cannot use Up, Down, PgUp, Ese ... etc. within "`" menu */
 
     TEST_CASE_INIT();
-    ibus_chewing_pre_edit_set_apply_property_boolean(
-        self, "vertical-lookup-table", TRUE);
+    g_object_set(G_OBJECT(self->engine), "vertical-lookup-table", TRUE, NULL);
 
     key_press_from_string("`");
     g_assert(ibus_chewing_pre_edit_has_flag(self, FLAG_TABLE_SHOW));
@@ -856,16 +792,18 @@ void test_keypad() {
 
 gint main(gint argc, gchar **argv) {
     g_test_init(&argc, &argv, NULL);
-    MkdgBackend *backend = mkdg_g_settings_backend_new(
-        QUOTE_ME(PROJECT_SCHEMA_ID), QUOTE_ME(PROJECT_SCHEMA_DIR), NULL);
     mkdg_log_set_level(DEBUG);
-    self = ibus_chewing_pre_edit_new(backend);
-    ibus_chewing_pre_edit_use_all_configure(self);
-
+    IBusChewingEngine *engine = g_object_new(IBUS_TYPE_CHEWING_ENGINE, NULL);
+    self = engine->icPreEdit;
     g_assert(self != NULL);
+
+    g_object_set(G_OBJECT(self->engine), "auto-shift-cur", TRUE, NULL);
+    g_object_set(G_OBJECT(self->engine), "enable-fullwidth-toggle-key", TRUE, NULL);
+
     TEST_RUN_THIS(filter_modifiers_test);
     TEST_RUN_THIS(self_key_sym_fix_test);
     TEST_RUN_THIS(self_handle_key_sym_default_test);
+    TEST_RUN_THIS(process_key_default_english_test);
     TEST_RUN_THIS(process_key_normal_test);
     TEST_RUN_THIS(process_key_text_with_symbol_test);
     TEST_RUN_THIS(process_key_mix_test);
